@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
@@ -47,7 +46,7 @@ class NeighborsNotComputedChemenvError(AbstractChemenvError):
         self.site = site
 
     def __str__(self):
-        return "The neighbors were not computed for the following site : \n" + str(self.site)
+        return f"The neighbors were not computed for the following site : \n{self.site}"
 
 
 class EquivalentSiteSearchError(AbstractChemenvError):
@@ -62,7 +61,7 @@ class EquivalentSiteSearchError(AbstractChemenvError):
         self.site = site
 
     def __str__(self):
-        return "Equivalent site could not be found for the following site : {}".format(str(self.site))
+        return f"Equivalent site could not be found for the following site : {self.site}"
 
 
 class SolidAngleError(AbstractChemenvError):
@@ -77,9 +76,7 @@ class SolidAngleError(AbstractChemenvError):
         self.cosinus = cosinus
 
     def __str__(self):
-        return "Value of cosinus ({}) from which an angle should be retrieved" "is not between -1.0 and 1.0".format(
-            self.cosinus
-        )
+        return f"Value of cosinus ({self.cosinus}) from which an angle should be retrieved is not between -1.0 and 1.0"
 
 
 class ChemenvError(Exception):
@@ -98,4 +95,4 @@ class ChemenvError(Exception):
         self.msg = msg
 
     def __str__(self):
-        return str(self.cls) + ": " + self.method + "\n" + repr(self.msg)
+        return f"{self.cls}: {self.method}\n{self.msg}"
