@@ -38,7 +38,7 @@ logger = logging.getLogger(__name__)
 
 class FreysoldtCorrection(DefectCorrection):
     """
-    A class for FreysoldtCorrection class. Largely adapated from PyCDT code
+    A class for FreysoldtCorrection class. Largely adapted from PyCDT code
 
     If this correction is used, please reference Freysoldt's original paper.
     doi: 10.1103/PhysRevLett.102.016402
@@ -165,7 +165,7 @@ class FreysoldtCorrection(DefectCorrection):
 
     def perform_es_corr(self, lattice, q, step=1e-4):
         """
-        Peform Electrostatic Freysoldt Correction
+        Perform Electrostatic Freysoldt Correction
         Args:
             lattice: Pymatgen lattice object
             q (int): Charge of defect
@@ -182,14 +182,14 @@ class FreysoldtCorrection(DefectCorrection):
 
         def e_iso(encut):
             gcut = eV_to_k(encut)  # gcut is in units of 1/A
-            return scipy.integrate.quad(lambda g: self.q_model.rho_rec(g * g) ** 2, step, gcut)[0] * (q ** 2) / np.pi
+            return scipy.integrate.quad(lambda g: self.q_model.rho_rec(g * g) ** 2, step, gcut)[0] * (q**2) / np.pi
 
         def e_per(encut):
             eper = 0
             for g2 in generate_reciprocal_vectors_squared(a1, a2, a3, encut):
                 eper += (self.q_model.rho_rec(g2) ** 2) / g2
-            eper *= (q ** 2) * 2 * round(np.pi, 6) / vol
-            eper += (q ** 2) * 4 * round(np.pi, 6) * self.q_model.rho_rec_limit0 / vol
+            eper *= (q**2) * 2 * round(np.pi, 6) / vol
+            eper += (q**2) * 4 * round(np.pi, 6) * self.q_model.rho_rec_limit0 / vol
             return eper
 
         eiso = converge(e_iso, 5, self.madetol, self.energy_cutoff)
@@ -274,12 +274,12 @@ class FreysoldtCorrection(DefectCorrection):
         v_G[1:] = 4 * np.pi / (self.dielectric * g2) * -q * self.q_model.rho_rec(g2)
         v_G[nx // 2] = 0 if not (nx % 2) else v_G[nx // 2]
 
-        # Get the real space potential by peforming a  fft and grabbing the imaginary portion
+        # Get the real space potential by performing a  fft and grabbing the imaginary portion
         v_R = np.fft.fft(v_G)
 
         if abs(np.imag(v_R).max()) > self.madetol:
             raise Exception("imaginary part found to be %s", repr(np.imag(v_R).max()))
-        v_R /= lattice.volume * ang_to_bohr ** 3
+        v_R /= lattice.volume * ang_to_bohr**3
         v_R = np.real(v_R) * hart_to_ev
 
         # get correction
@@ -369,7 +369,7 @@ class FreysoldtCorrection(DefectCorrection):
 
 class KumagaiCorrection(DefectCorrection):
     """
-    A class for KumagaiCorrection class. Largely adapated from PyCDT code
+    A class for KumagaiCorrection class. Largely adapted from PyCDT code
 
     If this correction is used, please reference Kumagai and Oba's original paper
     (doi: 10.1103/PhysRevB.89.195205) as well as Freysoldt's original
@@ -469,7 +469,7 @@ class KumagaiCorrection(DefectCorrection):
             if abs(es_corr[0] - es_corr[1]) < 0.0001:
                 raise ValueError("Correction still not converged after trying prec_sets up to 35... serious error.")
 
-        es_corr = es_corr[0] * -(q ** 2.0) * kumagai_to_V / 2.0  # [eV]
+        es_corr = es_corr[0] * -(q**2.0) * kumagai_to_V / 2.0  # [eV]
 
         # if no sampling radius specified for pot align, then assuming Wigner-Seitz radius:
         if not self.metadata["sampling_radius"]:
@@ -508,7 +508,7 @@ class KumagaiCorrection(DefectCorrection):
 
     def perform_es_corr(self, gamma, prec, lattice, charge):
         """
-        Peform Electrostatic Kumagai Correction
+        Perform Electrostatic Kumagai Correction
         Args:
             gamma (float): Ewald parameter
             prec (int): Precision parameter for reciprical/real lattice vector generation
@@ -530,7 +530,7 @@ class KumagaiCorrection(DefectCorrection):
             + self.get_self_interaction(gamma)
         )
 
-        es_corr *= -(charge ** 2.0) * kumagai_to_V / 2.0  # [eV]
+        es_corr *= -(charge**2.0) * kumagai_to_V / 2.0  # [eV]
 
         return es_corr
 
@@ -548,7 +548,7 @@ class KumagaiCorrection(DefectCorrection):
         """
         For performing potential alignment in manner described by Kumagai et al.
         Args:
-            defect_structure: Pymatgen Structure object corrsponding to the defect supercell
+            defect_structure: Pymatgen Structure object corresponding to the defect supercell
 
             defect_frac_coords (array): Defect Position in fractional coordinates of the supercell
                 given in bulk_structure
@@ -674,7 +674,7 @@ class KumagaiCorrection(DefectCorrection):
             # dont need to avoid G=0, because it will not be
             # in recip list (if generate_R_and_G_vecs is used)
             Gdotdiel = np.dot(g_vec, np.dot(self.dielectric, g_vec))
-            summand = np.exp(-Gdotdiel / (4 * (gamma ** 2))) * np.cos(np.dot(g_vec, r)) / Gdotdiel
+            summand = np.exp(-Gdotdiel / (4 * (gamma**2))) * np.cos(np.dot(g_vec, r)) / Gdotdiel
             recip_part += summand
 
         recip_part /= volume
@@ -702,7 +702,7 @@ class KumagaiCorrection(DefectCorrection):
         Returns:
             Potential shift for defect.
         """
-        return -0.25 / (volume * gamma ** 2.0)
+        return -0.25 / (volume * gamma**2.0)
 
     def plot(self, title=None, saved=False):
         """
