@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
@@ -14,8 +13,8 @@ from typing import Dict
 from warnings import warn
 
 import numpy as np
-import scipy.constants as constants
 from monty.json import MSONable
+from scipy import constants
 from scipy.special import comb, erfc
 
 from pymatgen.core.structure import Structure
@@ -99,12 +98,12 @@ class EwaldSummation(MSONable):
 
         self._acc_factor = acc_factor
         # set screening length
-        self._eta = eta if eta else (len(structure) * w / (self._vol ** 2)) ** (1 / 3) * pi
+        self._eta = eta if eta else (len(structure) * w / (self._vol**2)) ** (1 / 3) * pi
         self._sqrt_eta = sqrt(self._eta)
 
         # acc factor used to automatically determine the optimal real and
         # reciprocal space cutoff radii
-        self._accf = sqrt(log(10 ** acc_factor))
+        self._accf = sqrt(log(10**acc_factor))
 
         self._rmax = real_space_cut if real_space_cut else self._accf / self._sqrt_eta
         self._gmax = recip_space_cut if recip_space_cut else 2 * self._sqrt_eta * self._accf
@@ -125,7 +124,7 @@ class EwaldSummation(MSONable):
 
         # Compute the correction for a charged cell
         self._charged_cell_energy = (
-            -EwaldSummation.CONV_FACT / 2 * np.pi / structure.volume / self._eta * structure.charge ** 2
+            -EwaldSummation.CONV_FACT / 2 * np.pi / structure.volume / self._eta * structure.charge**2
         )
 
     def compute_partial_energy(self, removed_indices):
@@ -179,7 +178,7 @@ class EwaldSummation(MSONable):
             output = ["Missing sites."]
             for site in sub_structure:
                 if site not in matches:
-                    output.append("unmatched = {}".format(site))
+                    output.append(f"unmatched = {site}")
             raise ValueError("\n".join(output))
 
         return sum(sum(total_energy_matrix))
@@ -272,8 +271,8 @@ class EwaldSummation(MSONable):
             self._initialized = True
 
         totalenergy = self._recip + self._real
-        for i in range(len(self._point)):
-            totalenergy[i, i] += self._point[i]
+        for i, energy in enumerate(self._point):
+            totalenergy[i, i] += energy
         return totalenergy
 
     @property
@@ -336,7 +335,7 @@ class EwaldSummation(MSONable):
         frac_coords = [fcoords for (fcoords, dist, i, img) in recip_nn if dist != 0]
 
         gs = rcp_latt.get_cartesian_coords(frac_coords)
-        g2s = np.sum(gs ** 2, 1)
+        g2s = np.sum(gs**2, 1)
         expvals = np.exp(-g2s / (4 * self._eta))
         grs = np.sum(gs[:, None] * coords[None, :], 2)
 
@@ -365,7 +364,7 @@ class EwaldSummation(MSONable):
                 forces += factor[:, None] * g[None, :]
 
         forces *= EwaldSummation.CONV_FACT
-        erecip *= prefactor * EwaldSummation.CONV_FACT * qiqj * 2 ** 0.5
+        erecip *= prefactor * EwaldSummation.CONV_FACT * qiqj * 2**0.5
         return erecip, forces
 
     def _calc_real_and_point(self):
@@ -382,7 +381,7 @@ class EwaldSummation(MSONable):
 
         qs = np.array(self._oxi_states)
 
-        epoint = -(qs ** 2) * sqrt(self._eta / pi)
+        epoint = -(qs**2) * sqrt(self._eta / pi)
 
         for i in range(numsites):
             nfcoords, rij, js, _ = self._s.lattice.get_points_in_sphere(
@@ -408,7 +407,7 @@ class EwaldSummation(MSONable):
             if self._compute_forces:
                 nccoords = self._s.lattice.get_cartesian_coords(nfcoords)
 
-                fijpf = qj / rij ** 3 * (erfcval + forcepf * rij * np.exp(-self._eta * rij ** 2))
+                fijpf = qj / rij**3 * (erfcval + forcepf * rij * np.exp(-self._eta * rij**2))
                 forces[i] += np.sum(
                     np.expand_dims(fijpf, 1) * (np.array([coords[i]]) - nccoords) * qi * EwaldSummation.CONV_FACT,
                     axis=0,
@@ -471,9 +470,15 @@ class EwaldSummation(MSONable):
         return d
 
     @classmethod
-    def from_dict(cls, d: Dict, fmt: str = None, **kwargs):
-        """
-        Create an EwaldSummation instance from json serialized dictionary.
+    def from_dict(cls, d: Dict, fmt: str = None, **kwargs) -> "EwaldSummation":
+        """Create an EwaldSummation instance from JSON serialized dictionary.
+
+        Args:
+            d (Dict): Dictionary representation
+            fmt (str, optional): Unused. Defaults to None.
+
+        Returns:
+            EwaldSummation: class instance
         """
         summation = cls(
             structure=Structure.from_dict(d["structure"]),
@@ -560,7 +565,7 @@ class EwaldMinimizer:
         self._num_to_return = num_to_return
         self._algo = algo
         if algo == EwaldMinimizer.ALGO_COMPLETE:
-            raise NotImplementedError("Complete algo not yet implemented for " "EwaldMinimizer")
+            raise NotImplementedError("Complete algo not yet implemented for EwaldMinimizer")
 
         self._output_lists = []
         # Tag that the recurse function looks at at each level. If a method
@@ -579,7 +584,7 @@ class EwaldMinimizer:
         This method finds and returns the permutations that produce the lowest
         ewald sum calls recursive function to iterate through permutations
         """
-        if self._algo == EwaldMinimizer.ALGO_FAST or self._algo == EwaldMinimizer.ALGO_BEST_FIRST:
+        if self._algo in (EwaldMinimizer.ALGO_FAST, EwaldMinimizer.ALGO_BEST_FIRST):
             return self._recurse(self._matrix, self._m_list, set(range(len(self._matrix))))
         return None
 
@@ -698,7 +703,7 @@ class EwaldMinimizer:
                     self.add_m_list(matrix_sum, output_m_list)
                 return
 
-        # if we wont have enough indices left, return
+        # if we won't have enough indices left, return
         if m_list[-1][1] > len(indices.intersection(m_list[-1][2])):
             return
 
@@ -761,7 +766,7 @@ def compute_average_oxidation_state(site):
         Average oxidation state of site.
     """
     try:
-        avg_oxi = sum([sp.oxi_state * occu for sp, occu in site.species.items() if sp is not None])
+        avg_oxi = sum(sp.oxi_state * occu for sp, occu in site.species.items() if sp is not None)
         return avg_oxi
     except AttributeError:
         pass
