@@ -361,7 +361,7 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
                 OBMol object
             ilabel1: inchi label map of the first molecule
             ilabel2: inchi label map of the second molecule
-            eq_atoms: equivalent atom lables
+            eq_atoms: equivalent atom labels
 
         Return:
             corrected inchi labels of heavy atoms of the second molecule
@@ -961,7 +961,7 @@ class BruteForceOrderMatcher(KabschMatcher):
     @staticmethod
     def permutations(atoms):
         """Generates all the possible permutations of atom order. To achieve better
-        performance all tha cases where the atoms are different has been ignored.
+        performance all the cases where the atoms are different has been ignored.
         """
         element_iterators = [itertools.permutations(np.where(atoms == element)[0]) for element in np.unique(atoms)]
 
@@ -1291,7 +1291,7 @@ class GeneticOrderMatcher(KabschMatcher):
         if sorted(p_atoms) != sorted(q_atoms):
             raise ValueError("The number of the same species aren't matching!")
 
-        # starting maches (only based on element)
+        # starting matches (only based on element)
         partial_matches = [[j] for j in range(self.N) if p_atoms[j] == q_atoms[0]]
 
         for i in range(1, self.N):
