@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 """
@@ -21,10 +20,10 @@ import warnings
 from copy import deepcopy
 from functools import cmp_to_key, lru_cache, partial
 from multiprocessing import Pool
+from typing import Dict, List, Optional, Union
 
 import numpy as np
 from monty.json import MontyDecoder, MSONable
-from monty.dev import deprecated
 from scipy.spatial import ConvexHull, HalfspaceIntersection
 
 try:
@@ -41,9 +40,7 @@ from pymatgen.entries.compatibility import MU_H2O
 from pymatgen.entries.computed_entries import ComputedEntry
 from pymatgen.util.coord import Simplex
 from pymatgen.util.plotting import pretty_plot
-from pymatgen.util.string import latexify
-from pymatgen.util.sequence import PBar
-
+from pymatgen.util.string import Stringify
 
 __author__ = "Sai Jayaraman"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -63,7 +60,7 @@ PREFAC = 0.0591
 # TODO: PourbaixEntries depend implicitly on having entry energies be
 #       formation energies, should be a better way to get from raw energies
 # TODO: uncorrected_energy is a bit of a misnomer, but not sure what to rename
-class PourbaixEntry(MSONable):
+class PourbaixEntry(MSONable, Stringify):
     """
     An object encompassing all data relevant to a solid or ion
     in a pourbaix diagram.  Each bulk solid/ion has an energy
@@ -230,13 +227,13 @@ class PourbaixEntry(MSONable):
     @classmethod
     def from_dict(cls, d):
         """
-        Invokes
+        Invokes a PourbaixEntry from a dictionary
         """
         entry_type = d["entry_type"]
         if entry_type == "Ion":
             entry = IonEntry.from_dict(d["entry"])
         else:
-            entry = PDEntry.from_dict(d["entry"])
+            entry = MontyDecoder().process_decoded(d["entry"])
         entry_id = d["entry_id"]
         concentration = d["concentration"]
         return PourbaixEntry(entry, entry_id, concentration)
@@ -262,6 +259,15 @@ class PourbaixEntry(MSONable):
         """
         return self.composition.num_atoms
 
+    def to_pretty_string(self) -> str:
+        """
+        :return: A pretty string representation.
+        """
+        if self.phase_type == "Solid":
+            return self.entry.composition.reduced_formula + "(s)"
+
+        return self.entry.name
+
     def __repr__(self):
         return "Pourbaix Entry : {} with energy = {:.4f}, npH = {}, nPhi = {}, nH2O = {}, entry_id = {} ".format(
             self.entry.composition,
@@ -296,7 +302,7 @@ class MultiEntry(PourbaixEntry):
             self.weights = weights
         self.entry_list = entry_list
 
-    @lru_cache()
+    @lru_cache
     def __getattr__(self, item):
         """
         Because most of the attributes here are just weighted
@@ -319,7 +325,7 @@ class MultiEntry(PourbaixEntry):
             else:
                 start = 0
             return sum(
-                [getattr(e, item) * w for e, w in zip(self.entry_list, self.weights)],
+                (getattr(e, item) * w for e, w in zip(self.entry_list, self.weights)),
                 start,
             )
 
@@ -414,7 +420,7 @@ class IonEntry(PDEntry):
         return d
 
     def __repr__(self):
-        return "IonEntry : {} with energy = {:.4f}".format(self.composition, self.energy)
+        return f"IonEntry : {self.composition} with energy = {self.energy:.4f}"
 
     def __str__(self):
         return self.__repr__()
@@ -458,28 +464,41 @@ class PourbaixDiagram(MSONable):
     Class to create a Pourbaix diagram from entries
     """
 
-    def __init__(self, entries, comp_dict=None, conc_dict=None, filter_solids=False, nproc=None):
+    def __init__(
+        self,
+        entries: Union[List[PourbaixEntry], List[MultiEntry]],
+        comp_dict: Optional[Dict[str, float]] = None,
+        conc_dict: Optional[Dict[str, float]] = None,
+        filter_solids: bool = True,
+        nproc: Optional[int] = None,
+    ):
         """
         Args:
             entries ([PourbaixEntry] or [MultiEntry]): Entries list
                 containing Solids and Ions or a list of MultiEntries
-            comp_dict ({str: float}): Dictionary of compositions,
+            comp_dict (dict[str, float]): Dictionary of compositions,
                 defaults to equal parts of each elements
-            conc_dict ({str: float}): Dictionary of ion concentrations,
+            conc_dict (dict[str, float]): Dictionary of ion concentrations,
                 defaults to 1e-6 for each element
-            filter_solids (bool): applying this filter to a pourbaix
-                diagram ensures all included phases are filtered by
-                stability on the compositional phase diagram.  This
-                breaks some of the functionality of the analysis,
-                though, so use with caution.
+            filter_solids (bool): applying this filter to a Pourbaix
+                diagram ensures all included solid phases are filtered by
+                stability on the compositional phase diagram. Defaults to True.
+                The practical consequence of this is that highly oxidized or reduced
+                phases that might show up in experiments due to kinetic limitations
+                on oxygen/hydrogen evolution won't appear in the diagram, but they are
+                not actually "stable" (and are frequently overstabilized from DFT errors).
+                Hence, including only the stable solid phases generally leads to the
+                most accurate Pourbaix diagrams.
             nproc (int): number of processes to generate multientries with
                 in parallel.  Defaults to None (serial processing)
         """
         entries = deepcopy(entries)
+        self.filter_solids = filter_solids
 
         # Get non-OH elements
-        self.pbx_elts = set(itertools.chain.from_iterable([entry.composition.elements for entry in entries]))
-        self.pbx_elts = list(self.pbx_elts - ELEMENTS_HO)
+        self.pbx_elts = list(
+            set(itertools.chain.from_iterable([entry.composition.elements for entry in entries])) - ELEMENTS_HO
+        )
         self.dim = len(self.pbx_elts) - 1
 
         # Process multientry inputs
@@ -516,21 +535,20 @@ class PourbaixDiagram(MSONable):
                 if len(ion_elts) == 1:
                     entry.concentration = conc_dict[ion_elts[0].symbol] * entry.normalization_factor
                 elif len(ion_elts) > 1 and not entry.concentration:
-                    raise ValueError("Elemental concentration not compatible " "with multi-element ions")
+                    raise ValueError("Elemental concentration not compatible with multi-element ions")
 
             self._unprocessed_entries = solid_entries + ion_entries
 
             if not len(solid_entries + ion_entries) == len(entries):
                 raise ValueError("All supplied entries must have a phase type of " 'either "Solid" or "Ion"')
 
-            if filter_solids:
+            if self.filter_solids:
                 # O is 2.46 b/c pbx entry finds energies referenced to H2O
                 entries_HO = [ComputedEntry("H", 0), ComputedEntry("O", 2.46)]
                 solid_pd = PhaseDiagram(solid_entries + entries_HO)
                 solid_entries = list(set(solid_pd.stable_entries) - set(entries_HO))
 
             self._filtered_entries = solid_entries + ion_entries
-
             if len(comp_dict) > 1:
                 self._multielement = True
                 self._processed_entries = self._preprocess_pourbaix_entries(self._filtered_entries, nproc=nproc)
@@ -640,7 +658,7 @@ class PourbaixDiagram(MSONable):
         combos = []
         for facet in valid_facets:
             for i in range(1, self.dim + 2):
-                these_combos = list()
+                these_combos = []
                 for combo in itertools.combinations(facet, i):
                     these_entries = [min_entries[i] for i in combo]
                     these_combos.append(frozenset(these_entries))
@@ -659,11 +677,11 @@ class PourbaixDiagram(MSONable):
         if nproc is not None:
             f = partial(self.process_multientry, prod_comp=tot_comp)
             with Pool(nproc) as p:
-                multi_entries = list(PBar(p.imap(f, all_combos), total=len(all_combos)))
+                multi_entries = list(p.imap(f, all_combos))
             multi_entries = list(filter(bool, multi_entries))
         else:
             # Serial processing of multi-entry generation
-            for combo in PBar(all_combos):
+            for combo in all_combos:
                 multi_entry = self.process_multientry(combo, prod_comp=tot_comp)
                 if multi_entry:
                     multi_entries.append(multi_entry)
@@ -696,17 +714,15 @@ class PourbaixDiagram(MSONable):
 
         # Generate and filter entries
         processed_entries = []
-        total = sum([comb(len(entries), j + 1) for j in range(N)])
+        total = sum(comb(len(entries), j + 1) for j in range(N))
         if total > 1e6:
-            warnings.warn(
-                "Your pourbaix diagram includes {} entries and may " "take a long time to generate.".format(total)
-            )
+            warnings.warn(f"Your pourbaix diagram includes {total} entries and may take a long time to generate.")
 
         # Parallel processing of multi-entry generation
         if nproc is not None:
             f = partial(self.process_multientry, prod_comp=total_comp)
             with Pool(nproc) as p:
-                processed_entries = list(PBar(p.imap(f, entry_combos), total=total))
+                processed_entries = list(p.imap(f, entry_combos))
             processed_entries = list(filter(bool, processed_entries))
         # Serial processing of multi-entry generation
         else:
@@ -874,7 +890,7 @@ class PourbaixDiagram(MSONable):
             {elt: coeff for elt, coeff in entry.composition.items() if elt not in ELEMENTS_HO}
         ).fractional_composition
         if entry_pbx_comp != pbx_comp:
-            raise ValueError("Composition of stability entry does not match " "Pourbaix Diagram")
+            raise ValueError("Composition of stability entry does not match Pourbaix Diagram")
         entry_normalized_energy = entry.normalized_energy_at_conditions(pH, V)
         hull_energy = self.get_hull_energy(pH, V)
         decomposition_energy = entry_normalized_energy - hull_energy
@@ -946,24 +962,31 @@ class PourbaixDiagram(MSONable):
         """
         return self._unprocessed_entries
 
-    def as_dict(self, include_unprocessed_entries=False):
+    def as_dict(self, include_unprocessed_entries=None):
         """
         Args:
-            include_unprocessed_entries (): Whether to include unprocessed entries.
+            include_unprocessed_entries (): DEPRECATED. Whether to include unprocessed
+                entries (equivalent to filter_solids=False). Serialization now includes
+                all unprocessed entries by default. Set filter_solids=False before
+                serializing to include unstable solids from the generated Pourbaix Diagram.
 
         Returns:
             MSONable dict.
         """
         if include_unprocessed_entries:
-            entries = [e.as_dict() for e in self._unprocessed_entries]
-        else:
-            entries = [e.as_dict() for e in self._processed_entries]
+            warnings.warn(
+                DeprecationWarning(
+                    "The include_unprocessed_entries kwarg is deprecated! "
+                    "Set filter_solids=True / False before serializing instead."
+                )
+            )
         d = {
             "@module": self.__class__.__module__,
             "@class": self.__class__.__name__,
-            "entries": entries,
+            "entries": [e.as_dict() for e in self._unprocessed_entries],
             "comp_dict": self._elt_comp,
             "conc_dict": self._conc_dict,
+            "filter_solids": self.filter_solids,
         }
         return d
 
@@ -977,7 +1000,7 @@ class PourbaixDiagram(MSONable):
             PourbaixDiagram
         """
         decoded_entries = MontyDecoder().process_decoded(d["entries"])
-        return cls(decoded_entries, d.get("comp_dict"), d.get("conc_dict"))
+        return cls(decoded_entries, d.get("comp_dict"), d.get("conc_dict"), d.get("filter_solids"))
 
 
 class PourbaixPlotter:
@@ -1006,7 +1029,16 @@ class PourbaixPlotter:
         plt = self.get_pourbaix_plot(*args, **kwargs)
         plt.show()
 
-    def get_pourbaix_plot(self, limits=None, title="", label_domains=True, plt=None):
+    def get_pourbaix_plot(
+        self,
+        limits=None,
+        title="",
+        label_domains=True,
+        label_fontsize=20,
+        show_water_lines=True,
+        show_neutral_axes=True,
+        plt=None,
+    ):
         """
         Plot Pourbaix diagram.
 
@@ -1015,6 +1047,11 @@ class PourbaixPlotter:
                 of the form [[xlo, xhi], [ylo, yhi]]
             title (str): Title to display on plot
             label_domains (bool): whether to label pourbaix domains
+            label_fontsize: font size for domain labels
+            show_water_lines: whether to show dashed lines indicating the region
+                of water stability.
+            show_neutral_axes; whether to show dashed horizontal and vertical lines
+                at 0 V and pH 7, respectively.
             plt (pyplot): Pyplot instance for plotting
 
         Returns:
@@ -1028,19 +1065,22 @@ class PourbaixPlotter:
         xlim = limits[0]
         ylim = limits[1]
 
-        h_line = np.transpose([[xlim[0], -xlim[0] * PREFAC], [xlim[1], -xlim[1] * PREFAC]])
-        o_line = np.transpose([[xlim[0], -xlim[0] * PREFAC + 1.23], [xlim[1], -xlim[1] * PREFAC + 1.23]])
-        neutral_line = np.transpose([[7, ylim[0]], [7, ylim[1]]])
-        V0_line = np.transpose([[xlim[0], 0], [xlim[1], 0]])
-
         ax = plt.gca()
         ax.set_xlim(xlim)
         ax.set_ylim(ylim)
         lw = 3
-        plt.plot(h_line[0], h_line[1], "r--", linewidth=lw)
-        plt.plot(o_line[0], o_line[1], "r--", linewidth=lw)
-        plt.plot(neutral_line[0], neutral_line[1], "k-.", linewidth=lw)
-        plt.plot(V0_line[0], V0_line[1], "k-.", linewidth=lw)
+
+        if show_water_lines:
+            h_line = np.transpose([[xlim[0], -xlim[0] * PREFAC], [xlim[1], -xlim[1] * PREFAC]])
+            o_line = np.transpose([[xlim[0], -xlim[0] * PREFAC + 1.23], [xlim[1], -xlim[1] * PREFAC + 1.23]])
+            plt.plot(h_line[0], h_line[1], "r--", linewidth=lw)
+            plt.plot(o_line[0], o_line[1], "r--", linewidth=lw)
+
+        if show_neutral_axes:
+            neutral_line = np.transpose([[7, ylim[0]], [7, ylim[1]]])
+            V0_line = np.transpose([[xlim[0], 0], [xlim[1], 0]])
+            plt.plot(neutral_line[0], neutral_line[1], "k-.", linewidth=lw)
+            plt.plot(V0_line[0], V0_line[1], "k-.", linewidth=lw)
 
         for entry, vertices in self._pbx._stable_domain_vertices.items():
             center = np.average(vertices, axis=0)
@@ -1053,7 +1093,7 @@ class PourbaixPlotter:
                     center,
                     ha="center",
                     va="center",
-                    fontsize=20,
+                    fontsize=label_fontsize,
                     color="b",
                 ).draggable()
 
@@ -1104,7 +1144,7 @@ class PourbaixPlotter:
         # Plot stability map
         plt.pcolor(pH, V, stability, cmap=cmap, vmin=0, vmax=e_hull_max)
         cbar = plt.colorbar()
-        cbar.set_label("Stability of {} (eV/atom)".format(generate_entry_label(entry)))
+        cbar.set_label(f"Stability of {generate_entry_label(entry)} (eV/atom)")
 
         # Set ticklabels
         # ticklabels = [t.get_text() for t in cbar.ax.get_yticklabels()]
@@ -1134,23 +1174,12 @@ def generate_entry_label(entry):
         entry (PourbaixEntry or MultiEntry): entry to get a label for
     """
     if isinstance(entry, MultiEntry):
-        return " + ".join([latexify_ion(latexify(e.name)) for e in entry.entry_list])
+        return " + ".join([e.name for e in entry.entry_list])
 
-    return latexify_ion(latexify(entry.name))
-
-
-@deprecated(
-    message="These methods have been deprecated in favor of using the Stringify mix-in class, which provides"
-    "to_latex_string, to_unicode_string, etc. They will be removed in v2022."
-)
-def latexify_ion(formula):
-    """
-    Convert a formula to latex format.
-
-    Args:
-        formula (str): Formula
-
-    Returns:
-        Latex string.
-    """
-    return re.sub(r"()\[([^)]*)\]", r"\1$^{\2}$", formula)
+    # TODO - a more elegant solution could be added later to Stringify
+    # for example, the pattern re.sub(r"([-+][\d\.]*)", r"$^{\1}$", )
+    # will convert B(OH)4- to B(OH)$_4^-$.
+    # for this to work, the ion's charge always must be written AFTER
+    # the sign (e.g., Fe+2 not Fe2+)
+    string = entry.to_latex_string()
+    return re.sub(r"()\[([^)]*)\]", r"\1$^{\2}$", string)
