@@ -6,17 +6,16 @@ https://www.brown.edu/Departments/Engineering/Labs/avdw/atat/
 import os
 import tempfile
 import warnings
-from pathlib import Path
-from subprocess import Popen, TimeoutExpired
 from collections import namedtuple
+from pathlib import Path
+from shutil import which
+from subprocess import Popen, TimeoutExpired
 from typing import Dict, List, Optional, Union
 
 from monty.dev import requires
-from monty.os.path import which
 
 from pymatgen.core.structure import Structure
 
-
 Sqs = namedtuple("Sqs", "bestsqs objective_function allsqs clusters directory")
 """
 Return type for run_mcsqs.
@@ -30,7 +29,7 @@ directory: str
 
 @requires(
     which("mcsqs") and which("str2cif"),
-    "run_mcsqs requires first installing AT-AT, " "see https://www.brown.edu/Departments/Engineering/Labs/avdw/atat/",
+    "run_mcsqs requires first installing AT-AT, see https://www.brown.edu/Departments/Engineering/Labs/avdw/atat/",
 )
 def run_mcsqs(
     structure: Structure,
@@ -91,8 +90,8 @@ def run_mcsqs(
     if isinstance(scaling, (int, float)):
 
         if scaling % 1:
-            raise ValueError("Scaling should be an integer, not {}".format(scaling))
-        mcsqs_find_sqs_cmd = ["mcsqs", "-n {}".format(scaling * num_atoms)]
+            raise ValueError(f"Scaling should be an integer, not {scaling}")
+        mcsqs_find_sqs_cmd = ["mcsqs", f"-n {scaling * num_atoms}"]
 
     else:
 
@@ -100,7 +99,7 @@ def run_mcsqs(
         with open("sqscell.out", "w") as f:
             f.write("1\n1 0 0\n0 1 0\n0 0 1\n")
         structure = structure * scaling
-        mcsqs_find_sqs_cmd = ["mcsqs", "-rc", "-n {}".format(num_atoms)]
+        mcsqs_find_sqs_cmd = ["mcsqs", "-rc", f"-n {num_atoms}"]
 
     structure.to(filename="rndstr.in")
 
@@ -110,30 +109,30 @@ def run_mcsqs(
         mcsqs_generate_clusters_cmd.append("-" + str(num) + "=" + str(clusters[num]))
 
     # Run mcsqs to find clusters
-    p = Popen(mcsqs_generate_clusters_cmd)
-    p.communicate()
+    with Popen(mcsqs_generate_clusters_cmd) as p:
+        p.communicate()
 
     # Generate SQS structures
     add_ons = [
-        "-T {}".format(temperature),
-        "-wr {}".format(wr),
-        "-wn {}".format(wn),
-        "-wd {}".format(wd),
-        "-tol {}".format(tol),
+        f"-T {temperature}",
+        f"-wr {wr}",
+        f"-wn {wn}",
+        f"-wd {wd}",
+        f"-tol {tol}",
     ]
 
     mcsqs_find_sqs_processes = []
     if instances and instances > 1:
         # if multiple instances, run a range of commands using "-ip"
         for i in range(instances):
-            instance_cmd = ["-ip {}".format(i + 1)]
+            instance_cmd = [f"-ip {i + 1}"]
             cmd = mcsqs_find_sqs_cmd + add_ons + instance_cmd
-            p = Popen(cmd)
+            p = Popen(cmd)  # pylint: disable=R1732
             mcsqs_find_sqs_processes.append(p)
     else:
         # run normal mcsqs command
         cmd = mcsqs_find_sqs_cmd + add_ons
-        p = Popen(cmd)
+        p = Popen(cmd)  # pylint: disable=R1732
         mcsqs_find_sqs_processes.append(p)
 
     try:
@@ -141,7 +140,7 @@ def run_mcsqs(
             p.communicate(timeout=search_time * 60)
 
         if instances and instances > 1:
-            p = Popen(["mcsqs", "-best"])
+            p = Popen(["mcsqs", "-best"])  # pylint: disable=R1732
             p.communicate()
 
         if os.path.exists("bestsqs.out") and os.path.exists("bestcorr.out"):
@@ -163,7 +162,7 @@ def run_mcsqs(
                     "is search_time sufficient or are number of instances too high?"
                 )
 
-            p = Popen(["mcsqs", "-best"])
+            p = Popen(["mcsqs", "-best"])  # pylint: disable=R1732
             p.communicate()
 
         if os.path.exists("bestsqs.out") and os.path.exists("bestcorr.out"):
@@ -191,15 +190,15 @@ def _parse_sqs_path(path) -> Sqs:
     detected_instances = len(list(path.glob("bestsqs*[0-9]*.out")))
 
     # Convert best SQS structure to cif file and pymatgen Structure
-    p = Popen("str2cif < bestsqs.out > bestsqs.cif", shell=True, cwd=path)
-    p.communicate()
+    with Popen("str2cif < bestsqs.out > bestsqs.cif", shell=True, cwd=path) as p:
+        p.communicate()
 
     with warnings.catch_warnings():
         warnings.simplefilter("ignore")
         bestsqs = Structure.from_file(path / "bestsqs.out")
 
     # Get best SQS objective function
-    with open(path / "bestcorr.out", "r") as f:
+    with open(path / "bestcorr.out") as f:
         lines = f.readlines()
 
     objective_function_str = lines[-1].split("=")[-1].strip()
@@ -213,15 +212,15 @@ def _parse_sqs_path(path) -> Sqs:
     allsqs = []
 
     for i in range(detected_instances):
-        sqs_out = "bestsqs{}.out".format(i + 1)
-        sqs_cif = "bestsqs{}.cif".format(i + 1)
-        corr_out = "bestcorr{}.out".format(i + 1)
-        p = Popen("str2cif < {} > {}".format(sqs_out, sqs_cif), shell=True, cwd=path)
-        p.communicate()
+        sqs_out = f"bestsqs{i + 1}.out"
+        sqs_cif = f"bestsqs{i + 1}.cif"
+        corr_out = f"bestcorr{i + 1}.out"
+        with Popen(f"str2cif < {sqs_out} > {sqs_cif}", shell=True, cwd=path) as p:
+            p.communicate()
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
             sqs = Structure.from_file(path / sqs_out)
-        with open(path / corr_out, "r") as f:
+        with open(path / corr_out) as f:
             lines = f.readlines()
 
         objective_function_str = lines[-1].split("=")[-1].strip()
@@ -253,7 +252,7 @@ def _parse_clusters(filename):
         List of dicts
     """
 
-    with open(filename, "r") as f:
+    with open(filename) as f:
         lines = f.readlines()
 
     clusters = []
