@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 """
@@ -10,13 +9,13 @@ import abc
 import os
 import warnings
 from collections import defaultdict
-from typing import List, Optional, Sequence, Union
+from typing import List, Optional, Sequence, Type, Union
 
 import numpy as np
 from monty.design_patterns import cached_class
-from monty.dev import deprecated
 from monty.json import MSONable
 from monty.serialization import loadfn
+from tqdm import tqdm
 from uncertainties import ufloat
 
 from pymatgen.analysis.structure_analyzer import oxide_type, sulfide_type
@@ -26,20 +25,23 @@ from pymatgen.entries.computed_entries import (
     ComputedEntry,
     ComputedStructureEntry,
     ConstantEnergyAdjustment,
+    EnergyAdjustment,
     TemperatureEnergyAdjustment,
 )
 from pymatgen.io.vasp.sets import MITRelaxSet, MPRelaxSet
 
-MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
-MU_H2O = -2.4583  # Free energy of formation of water, eV/H2O, used by MaterialsProjectAqueousCompatibility
-
-__author__ = "Ryan Kingsbury, Shyue Ping Ong, Anubhav Jain, Stephen Dacek, Sai Jayaraman"
+__author__ = "Amanda Wang, Ryan Kingsbury, Shyue Ping Ong, Anubhav Jain, Stephen Dacek, Sai Jayaraman"
 __copyright__ = "Copyright 2012-2020, The Materials Project"
 __version__ = "1.0"
 __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyuep@gmail.com"
 __date__ = "April 2020"
 
+MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
+MU_H2O = -2.4583  # Free energy of formation of water, eV/H2O, used by MaterialsProjectAqueousCompatibility
+
+AnyCompEntry = Union[ComputedEntry, ComputedStructureEntry]
+
 
 class CompatibilityError(Exception):
     """
@@ -47,8 +49,6 @@ class CompatibilityError(Exception):
     on incompatible calculation
     """
 
-    pass
-
 
 class Correction(metaclass=abc.ABCMeta):
     """
@@ -168,7 +168,7 @@ class PotcarCorrection(Correction):
         return ufloat(0.0, 0.0)
 
     def __str__(self):
-        return "{} Potcar Correction".format(self.input_set.__name__)
+        return f"{self.input_set.__name__} Potcar Correction"
 
 
 @cached_class
@@ -176,7 +176,7 @@ class GasCorrection(Correction):
     """
     Correct gas energies to obtain the right formation energies. Note that
     this depends on calculations being run within the same input set.
-    For old MaterialsProjectCompatibility and MITCompatibility.
+    Used by legacy MaterialsProjectCompatibility and MITCompatibility.
     """
 
     def __init__(self, config_file):
@@ -199,6 +199,10 @@ class GasCorrection(Correction):
 
         # set error to 0 because old MPCompatibility doesn't have errors
 
+        # only correct GGA or GGA+U entries
+        if entry.parameters.get("run_type", None) not in ["GGA", "GGA+U"]:
+            return ufloat(0.0, 0.0)
+
         rform = entry.composition.reduced_formula
         if rform in self.cpd_energies:
             correction += self.cpd_energies[rform] * comp.num_atoms - entry.uncorrected_energy
@@ -206,7 +210,7 @@ class GasCorrection(Correction):
         return correction
 
     def __str__(self):
-        return "{} Gas Correction".format(self.name)
+        return f"{self.name} Gas Correction"
 
 
 @cached_class
@@ -215,7 +219,7 @@ class AnionCorrection(Correction):
     Correct anion energies to obtain the right formation energies. Note that
     this depends on calculations being run within the same input set.
 
-    For old MaterialsProjectCompatibility and MITCompatibility.
+    Used by legacy MaterialsProjectCompatibility and MITCompatibility.
     """
 
     def __init__(self, config_file, correct_peroxide=True):
@@ -242,6 +246,10 @@ class AnionCorrection(Correction):
 
         correction = ufloat(0.0, 0.0)
 
+        # only correct GGA or GGA+U entries
+        if entry.parameters.get("run_type", None) not in ["GGA", "GGA+U"]:
+            return ufloat(0.0, 0.0)
+
         # Check for sulfide corrections
         if Element("S") in comp:
             sf_type = "sulfide"
@@ -298,7 +306,7 @@ class AnionCorrection(Correction):
         return correction
 
     def __str__(self):
-        return "{} Anion Correction".format(self.name)
+        return f"{self.name} Anion Correction"
 
 
 @cached_class
@@ -306,6 +314,8 @@ class AqueousCorrection(Correction):
     """
     This class implements aqueous phase compound corrections for elements
     and H2O.
+
+    Used only by MITAqueousCompatibility.
     """
 
     def __init__(self, config_file, error_file=None):
@@ -318,9 +328,7 @@ class AqueousCorrection(Correction):
         self.cpd_energies = c["AqueousCompoundEnergies"]
         # there will either be a CompositionCorrections OR an OxideCorrections key,
         # but not both, depending on the compatibility scheme we are using.
-        # TODO - the two lines below are specific to MaterialsProjectCompatibility
-        # and MaterialsProject2020Compatibility. Could be changed to be more general
-        # and/or streamlined if MaterialsProjectCompatibility is retired.
+        # MITCompatibility only uses OxideCorrections, and hence self.comp_correction is none.
         self.comp_correction = c.get("CompositionCorrections", defaultdict(float))
         self.oxide_correction = c.get("OxideCorrections", defaultdict(float))
         self.name = c["Name"]
@@ -340,7 +348,13 @@ class AqueousCorrection(Correction):
         comp = entry.composition
         rform = comp.reduced_formula
         cpdenergies = self.cpd_energies
+
+        # only correct GGA or GGA+U entries
+        if entry.parameters.get("run_type", None) not in ["GGA", "GGA+U"]:
+            return ufloat(0.0, 0.0)
+
         correction = ufloat(0.0, 0.0)
+
         if rform in cpdenergies:
             if rform in ["H2", "H2O"]:
                 corr = cpdenergies[rform] * comp.num_atoms - entry.uncorrected_energy - entry.correction
@@ -381,10 +395,11 @@ class AqueousCorrection(Correction):
                 # next, add MU_H2O for each water molecule present
                 correction += ufloat(-1 * MU_H2O * nH2O, 0.0)
                 # correction += 0.5 * 2.46 * nH2O  # this is the old way this correction was calculated
+
         return correction
 
     def __str__(self):
-        return "{} Aqueous Correction".format(self.name)
+        return f"{self.name} Aqueous Correction"
 
 
 @cached_class
@@ -433,7 +448,7 @@ class UCorrection(Correction):
             error_file: Path to the selected compatibilityErrors.yaml config file.
         """
         if compat_type not in ["GGA", "Advanced"]:
-            raise CompatibilityError("Invalid compat_type {}".format(compat_type))
+            raise CompatibilityError(f"Invalid compat_type {compat_type}")
 
         c = loadfn(config_file)
 
@@ -461,16 +476,21 @@ class UCorrection(Correction):
         """
         if entry.parameters.get("run_type") not in ["GGA", "GGA+U"]:
             raise CompatibilityError(
-                "Entry {} has invalid run type {}. Discarding.".format(entry.entry_id, entry.parameters.get("run_type"))
+                f"Entry {entry.entry_id} has invalid run type {entry.parameters.get('run_type')}. Discarding."
             )
 
         calc_u = entry.parameters.get("hubbards", None)
         calc_u = defaultdict(int) if calc_u is None else calc_u
         comp = entry.composition
 
-        elements = sorted([el for el in comp.elements if comp[el] > 0], key=lambda el: el.X)
+        elements = sorted((el for el in comp.elements if comp[el] > 0), key=lambda el: el.X)
         most_electroneg = elements[-1].symbol
         correction = ufloat(0.0, 0.0)
+
+        # only correct GGA or GGA+U entries
+        if entry.parameters.get("run_type", None) not in ["GGA", "GGA+U"]:
+            return ufloat(0.0, 0.0)
+
         ucorr = self.u_corrections.get(most_electroneg, {})
         usettings = self.u_settings.get(most_electroneg, {})
         uerrors = self.u_errors.get(most_electroneg, defaultdict(float))
@@ -479,14 +499,14 @@ class UCorrection(Correction):
             sym = el.symbol
             # Check for bad U values
             if calc_u.get(sym, 0) != usettings.get(sym, 0):
-                raise CompatibilityError("Invalid U value of %s on %s" % (calc_u.get(sym, 0), sym))
+                raise CompatibilityError(f"Invalid U value of {calc_u.get(sym, 0)} on {sym}")
             if sym in ucorr:
                 correction += ufloat(ucorr[sym], uerrors[sym]) * comp[el]
 
         return correction
 
     def __str__(self):
-        return "{} {} Correction".format(self.name, self.compat_type)
+        return f"{self.name} {self.compat_type} Correction"
 
 
 class Compatibility(MSONable, metaclass=abc.ABCMeta):
@@ -497,7 +517,7 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
     """
 
     @abc.abstractmethod
-    def get_adjustments(self, entry: ComputedEntry):
+    def get_adjustments(self, entry: AnyCompEntry) -> List[EnergyAdjustment]:
         """
         Get the energy adjustments for a ComputedEntry.
 
@@ -516,9 +536,8 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
         Raises:
             CompatibilityError if the entry is not compatible
         """
-        return
 
-    def process_entry(self, entry):
+    def process_entry(self, entry: ComputedEntry) -> Optional[ComputedEntry]:
         """
         Process a single entry with the chosen Corrections. Note
         that this method will change the data of the original entry.
@@ -529,11 +548,14 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
             An adjusted entry if entry is compatible, otherwise None is
             returned.
         """
-        if self.process_entries(entry):
+        try:
             return self.process_entries(entry)[0]
-        return None
+        except IndexError:
+            return None
 
-    def process_entries(self, entries: Union[ComputedEntry, list], clean: bool = True):
+    def process_entries(
+        self, entries: Union[AnyCompEntry, List[AnyCompEntry]], clean: bool = True, verbose: bool = False
+    ) -> List[ComputedEntry]:
         """
         Process a sequence of entries with the chosen Compatibility scheme. Note
         that this method will change the data of the original entries.
@@ -543,6 +565,8 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
             clean: bool, whether to remove any previously-applied energy adjustments.
                 If True, all EnergyAdjustment are removed prior to processing the Entry.
                 Default is True.
+            verbose: bool, whether to display progress bar for processing multiple entries.
+                Default is False.
 
         Returns:
             A list of adjusted entries.  Entries in the original list which
@@ -554,7 +578,7 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
 
         processed_entry_list = []
 
-        for entry in entries:
+        for entry in tqdm(entries, disable=(not verbose)):
             ignore_entry = False
             # if clean is True, remove all previous adjustments from the entry
             if clean:
@@ -563,9 +587,8 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
             # get the energy adjustments
             try:
                 adjustments = self.get_adjustments(entry)
-            except CompatibilityError as exc:
+            except CompatibilityError:
                 ignore_entry = True
-                print(exc)
                 continue
 
             for ea in adjustments:
@@ -612,9 +635,7 @@ class Compatibility(MSONable, metaclass=abc.ABCMeta):
         if len(entry.energy_adjustments) > 0:
             print("The following energy adjustments have been applied to this entry:")
             for e in entry.energy_adjustments:
-                print(
-                    "\t\t{}: {:.3f} eV ({:.3f} eV/atom)".format(e.name, e.value, e.value / entry.composition.num_atoms)
-                )
+                print(f"\t\t{e.name}: {e.value:.3f} eV ({e.value / entry.composition.num_atoms:.3f} eV/atom)")
         elif entry.correction == 0:
             print("No energy adjustments have been applied to this entry.")
 
@@ -746,18 +767,18 @@ class CorrectionsList(Compatibility):
             entry: A ComputedEntry.
         """
         d = self.get_explanation_dict(entry)
-        print("The uncorrected value of the energy of %s is %f eV" % (entry.composition, d["uncorrected_energy"]))
-        print("The following corrections / screening are applied for %s:\n" % d["compatibility"])
+        print(f"The uncorrected value of the energy of {entry.composition} is {d['uncorrected_energy']:f} eV")
+        print(f"The following corrections / screening are applied for {d['compatibility']}:\n")
         for c in d["corrections"]:
-            print("%s correction: %s\n" % (c["name"], c["description"]))
-            print("For the entry, this correction has the value %f eV." % c["value"])
+            print(f"{c['name']} correction: {c['description']}\n")
+            print(f"For the entry, this correction has the value {c['value']:f} eV.")
             if c["uncertainty"] != 0 or c["value"] == 0:
-                print("This correction has an uncertainty value of %f eV." % c["uncertainty"])
+                print(f"This correction has an uncertainty value of {c['uncertainty']:f} eV.")
             else:
                 print("This correction does not have uncertainty data available")
             print("-" * 30)
 
-        print("The final energy after corrections is %f" % d["corrected_energy"])
+        print(f"The final energy after corrections is {d['corrected_energy']:f}")
 
 
 class MaterialsProjectCompatibility(CorrectionsList):
@@ -769,12 +790,6 @@ class MaterialsProjectCompatibility(CorrectionsList):
     valid.
     """
 
-    @deprecated(
-        message=(
-            "MaterialsProjectCompatibility will be updated with new correction classes "
-            "as well as new values of corrections and uncertainties in 2020"
-        )
-    )
     def __init__(self, compat_type="Advanced", correct_peroxide=True, check_potcar_hash=False):
         """
         Args:
@@ -820,6 +835,7 @@ class MaterialsProject2020Compatibility(Compatibility):
         compat_type="Advanced",
         correct_peroxide=True,
         check_potcar_hash=False,
+        config_file=None,
     ):
         """
         Args:
@@ -848,24 +864,39 @@ class MaterialsProject2020Compatibility(Compatibility):
             check_potcar_hash (bool): Use potcar hash to verify POTCAR settings are
                 consistent with MPRelaxSet. If False, only the POTCAR symbols will
                 be used. (Default: False)
+            config_file (Path): Path to the selected compatibility.yaml config file.
+                If None, defaults to `MP2020Compatibility.yaml` distributed with
+                pymatgen.
 
         References:
-            Wang, A., et al. A framework for quantifying uncertainty in DFT energy corrections.
-                Under review.
+            Wang, A., Kingsbury, R., McDermott, M., Horton, M., Jain. A., Ong, S.P.,
+                Dwaraknath, S., Persson, K. A framework for quantifying uncertainty
+                in DFT energy corrections. Scientific Reports 11: 15496, 2021.
+                https://doi.org/10.1038/s41598-021-94550-5
 
             Jain, A. et al. Formation enthalpies by mixing GGA and GGA + U calculations.
                 Phys. Rev. B - Condens. Matter Mater. Phys. 84, 1–10 (2011).
         """
         if compat_type not in ["GGA", "Advanced"]:
-            raise CompatibilityError("Invalid compat_type {}".format(compat_type))
+            raise CompatibilityError(f"Invalid compat_type {compat_type}")
 
         self.compat_type = compat_type
         self.correct_peroxide = correct_peroxide
         self.check_potcar_hash = check_potcar_hash
 
         # load corrections and uncertainties
-        self.config_file = os.path.join(MODULE_DIR, "MP2020Compatibility.yaml")
-        c = loadfn(self.config_file)
+        if config_file:
+            if os.path.isfile(config_file):
+                self.config_file = config_file
+                c = loadfn(self.config_file)
+            else:
+                raise ValueError(
+                    f"Custom MaterialsProject2020Compatibility config_file ({config_file}) does not exist."
+                )
+        else:
+            self.config_file = None
+            c = loadfn(os.path.join(MODULE_DIR, "MP2020Compatibility.yaml"))
+
         self.name = c["Name"]
         self.comp_correction = c["Corrections"].get("CompositionCorrections", defaultdict(float))
         self.comp_errors = c["Uncertainties"].get("CompositionCorrections", defaultdict(float))
@@ -879,7 +910,7 @@ class MaterialsProject2020Compatibility(Compatibility):
             self.u_corrections = {}
             self.u_errors = {}
 
-    def get_adjustments(self, entry: Union[ComputedEntry, ComputedStructureEntry]):
+    def get_adjustments(self, entry: AnyCompEntry):
         """
         Get the energy adjustments for a ComputedEntry or ComputedStructureEntry.
 
@@ -915,7 +946,7 @@ class MaterialsProject2020Compatibility(Compatibility):
         comp = entry.composition
         rform = comp.reduced_formula
         # sorted list of elements, ordered by electronegativity
-        elements = sorted([el for el in comp.elements if comp[el] > 0], key=lambda el: el.X)
+        elements = sorted((el for el in comp.elements if comp[el] > 0), key=lambda el: el.X)
 
         # Skip single elements
         if len(comp) == 1:
@@ -994,27 +1025,45 @@ class MaterialsProject2020Compatibility(Compatibility):
                     self.comp_correction[ox_type],
                     comp["O"],
                     uncertainty_per_atom=self.comp_errors[ox_type],
-                    name="MP2020 anion correction ({})".format(ox_type),
+                    name=f"MP2020 anion correction ({ox_type})",
                     cls=self.as_dict(),
                 )
             )
 
         # Check for anion corrections
+        # only apply anion corrections if the element is an anion
+        # first check for a pre-populated oxidation states key
+        # the key is expected to comprise a dict corresponding to the first element output by
+        # Composition.oxi_state_guesses(), e.g. {'Al': 3.0, 'S': 2.0, 'O': -2.0} for 'Al2SO4'
+        if "oxidation_states" not in entry.data.keys():
+            # try to guess the oxidation states from composition
+            # for performance reasons, fail if the composition is too large
+            try:
+                oxi_states = entry.composition.oxi_state_guesses(max_sites=-20)
+            except ValueError:
+                oxi_states = []
+
+            if oxi_states == []:
+                entry.data["oxidation_states"] = {}
+            else:
+                entry.data["oxidation_states"] = oxi_states[0]
+
+        if entry.data["oxidation_states"] == {}:
+            warnings.warn(
+                f"Failed to guess oxidation states for Entry {entry.entry_id} "
+                f"({entry.composition.reduced_formula}). Assigning anion correction to "
+                "only the most electronegative atom."
+            )
+
         for anion in ["Br", "I", "Se", "Si", "Sb", "Te", "H", "N", "F", "Cl"]:
             if Element(anion) in comp and anion in self.comp_correction:
                 apply_correction = False
-                # only apply anion corrections if the element is an anion
-                # first check for a pre-populated oxidation states key
-                # the key is expected to comprise a dict corresponding to the first element output by
-                # Composition.oxi_state_guesses(), e.g. {'Al': 3.0, 'S': 2.0, 'O': -2.0} for 'Al2SO4'
-                if entry.data.get("oxidation_states"):
-                    if entry.data["oxidation_states"].get(anion, 0) < 0:
-                        apply_correction = True
+                # if the oxidation_states key is not populated, only apply the correction if the anion
+                # is the most electronegative element
+                if entry.data["oxidation_states"].get(anion, 0) < 0:
+                    apply_correction = True
                 else:
-                    # if the oxidation_states key is not populated, only apply the correction if the anion
-                    # is the most electronegative element
                     most_electroneg = elements[-1].symbol
-
                     if anion == most_electroneg:
                         apply_correction = True
 
@@ -1024,10 +1073,11 @@ class MaterialsProject2020Compatibility(Compatibility):
                             self.comp_correction[anion],
                             comp[anion],
                             uncertainty_per_atom=self.comp_errors[anion],
-                            name="MP2020 anion correction",
+                            name=f"MP2020 anion correction ({anion})",
                             cls=self.as_dict(),
                         )
                     )
+
         # GGA / GGA+U mixing scheme corrections
         calc_u = entry.parameters.get("hubbards", None)
         calc_u = defaultdict(int) if calc_u is None else calc_u
@@ -1040,14 +1090,14 @@ class MaterialsProject2020Compatibility(Compatibility):
             sym = el.symbol
             # Check for bad U values
             if calc_u.get(sym, 0) != usettings.get(sym, 0):
-                raise CompatibilityError("Invalid U value of {:.1f} on {}".format(calc_u.get(sym, 0), sym))
+                raise CompatibilityError(f"Invalid U value of {calc_u.get(sym, 0):.1f} on {sym}")
             if sym in ucorr:
                 adjustments.append(
                     CompositionEnergyAdjustment(
                         ucorr[sym],
                         comp[el],
                         uncertainty_per_atom=uerrors[sym],
-                        name="MP2020 GGA/GGA+U mixing correction ({})".format(sym),
+                        name=f"MP2020 GGA/GGA+U mixing correction ({sym})",
                         cls=self.as_dict(),
                     )
                 )
@@ -1141,8 +1191,7 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
            the experimental reaction energy of -2.458 eV/H2O is reproduced.
         2. Add entropy to the DFT energy of any compounds that are liquid or
            gaseous at room temperature
-        3. Adjust the energy of H2O for consistency with the adjusted H2 energy.
-        4. Adjust the DFT energies of solid hydrate compounds (compounds that
+        3. Adjust the DFT energies of solid hydrate compounds (compounds that
            contain water, e.g. FeO.nH2O) such that the energies of the embedded
            H2O molecules are equal to the experimental free energy
 
@@ -1158,7 +1207,7 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
 
     def __init__(
         self,
-        solid_compat: Optional[Compatibility] = MaterialsProjectCompatibility,
+        solid_compat: Optional[Union[Compatibility, Type[Compatibility]]] = MaterialsProject2020Compatibility,
         o2_energy: Optional[float] = None,
         h2o_energy: Optional[float] = None,
         h2o_adjustments: Optional[float] = None,
@@ -1168,14 +1217,14 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
 
         Note that this class requires as inputs the ground-state DFT energies of O2 and H2O, plus the value of any
         energy adjustments applied to an H2O molecule. If these parameters are not provided in __init__, they can
-        be automatically populated by including ComputedEntry for the ground state of O2 and H2O in a list of entries
-        passed to process_entries. process_entries will fail if one or the other is not provided.
+        be automatically populated by including ComputedEntry for the ground state of O2 and H2O in a list of
+        entries passed to process_entries. process_entries will fail if one or the other is not provided.
 
         Args:
-            solid_compat: Compatiblity scheme used to pre-process solid DFT energies prior to applying aqueous
-                energy adjustments. May be passed as a class (e.g. MaterialsProjectCompatibility) or an instance
-                (e.g., MaterialsProjectCompatibility()). If None, solid DFT energies are used as-is.
-                Default: MaterialsProjectCompatibility
+            solid_compat: Compatibility scheme used to pre-process solid DFT energies prior to applying aqueous
+                energy adjustments. May be passed as a class (e.g. MaterialsProject2020Compatibility) or an instance
+                (e.g., MaterialsProject2020Compatibility()). If None, solid DFT energies are used as-is.
+                Default: MaterialsProject2020Compatibility
             o2_energy: The ground-state DFT energy of oxygen gas, including any adjustments or corrections, in eV/atom.
                 If not set, this value will be determined from any O2 entries passed to process_entries.
                 Default: None
@@ -1186,13 +1235,20 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
                 If not set, this value will be determined from any H2O entries passed to process_entries.
                 Default: None
         """
-        self.solid_compat = solid_compat
-        if self.solid_compat:
-            if not isinstance(self.solid_compat, Compatibility):  # check whether solid_compat has been instantiated
-                self.solid_compat = solid_compat()
+        self.solid_compat = None
+        # check whether solid_compat has been instantiated
+        if solid_compat is None:
+            self.solid_compat = None
+        elif isinstance(solid_compat, type) and issubclass(solid_compat, Compatibility):
+            self.solid_compat = solid_compat()
+        elif issubclass(type(solid_compat), Compatibility):
+            self.solid_compat = solid_compat
+        else:
+            raise ValueError("Expected a Compatibility class, instance of a Compatibility or None")
 
         self.o2_energy = o2_energy
         self.h2o_energy = h2o_energy
+        self.h2_energy = None
         self.h2o_adjustments = h2o_adjustments
 
         if not all([self.o2_energy, self.h2o_energy, self.h2o_adjustments]):
@@ -1217,7 +1273,7 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
         self.name = "MP Aqueous free energy adjustment"
         super().__init__()
 
-    def get_adjustments(self, entry: ComputedEntry):
+    def get_adjustments(self, entry):
         """
         Returns the corrections applied to a particular entry.
 
@@ -1247,7 +1303,7 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
 
         # Free energy of H2 in eV/atom, fitted using Eq. 40 of Persson et al. PRB 2012 85(23)
         # for this calculation ONLY, we need the (corrected) DFT energy of water
-        self.h2_energy = round(
+        self.fit_h2_energy = round(
             0.5
             * (
                 3 * (self.h2o_energy - self.cpd_entropies["H2O"]) - (self.o2_energy - self.cpd_entropies["O2"]) - MU_H2O
@@ -1255,46 +1311,29 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
             6,
         )
 
-        # Free energy of H2O, fitted for consistency with the O2 and H2 energies.
-        self.fit_h2o_energy = round(
-            (2 * self.h2_energy + (self.o2_energy - self.cpd_entropies["O2"]) + MU_H2O) / 3,
-            6,
-        )
-
         comp = entry.composition
         rform = comp.reduced_formula
 
-        # pin the energy of all H2 entries to h2_energy
+        # use fit_h2_energy to adjust the energy of all H2 polymorphs such that
+        # the lowest energy polymorph has the correct experimental value
+        # if h2o and o2 energies have been set explicitly via kwargs, then
+        # all H2 polymorphs will get the same energy.
         if rform == "H2":
             adjustments.append(
                 ConstantEnergyAdjustment(
-                    self.h2_energy * comp.num_atoms - entry.energy,
+                    (self.fit_h2_energy - self.h2_energy) * comp.num_atoms,
                     uncertainty=np.nan,
                     name="MP Aqueous H2 / H2O referencing",
                     cls=self.as_dict(),
-                    description="Adjusts the H2 and H2O energy to reproduce the experimental "
+                    description="Adjusts the H2 energy to reproduce the experimental "
                     "Gibbs formation free energy of H2O, based on the DFT energy "
-                    "of Oxygen",
-                )
-            )
-
-        # pin the energy of all H2O entries to fit_h2o_energy
-        elif rform == "H2O":
-            adjustments.append(
-                ConstantEnergyAdjustment(
-                    self.fit_h2o_energy * comp.num_atoms - entry.energy,
-                    uncertainty=np.nan,
-                    name="MP Aqueous H2 / H2O referencing",
-                    cls=self.as_dict(),
-                    description="Adjusts the H2 and H2O energy to reproduce the experimental "
-                    "Gibbs formation free energy of H2O, based on the DFT energy "
-                    "of Oxygen",
+                    "of Oxygen and H2O",
                 )
             )
 
         # add minus T delta S to the DFT energy (enthalpy) of compounds that are
         # molecular-like at room temperature
-        elif rform in self.cpd_entropies and rform != "H2O":
+        if rform in self.cpd_entropies:
             adjustments.append(
                 TemperatureEnergyAdjustment(
                     -1 * self.cpd_entropies[rform] / 298,
@@ -1350,7 +1389,9 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
 
         return adjustments
 
-    def process_entries(self, entries: Union[ComputedEntry, list], clean: bool = False):
+    def process_entries(
+        self, entries: Union[ComputedEntry, List[ComputedEntry]], clean: bool = False, verbose: bool = False
+    ):
         """
         Process a sequence of entries with the chosen Compatibility scheme.
 
@@ -1359,6 +1400,8 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
             clean: bool, whether to remove any previously-applied energy adjustments.
                 If True, all EnergyAdjustment are removed prior to processing the Entry.
                 Default is False.
+            verbose: bool, whether to display progress bar for processing multiple entries.
+                Default is False.
 
         Returns:
             A list of adjusted entries.  Entries in the original list which
@@ -1372,17 +1415,36 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
         if self.solid_compat:
             entries = self.solid_compat.process_entries(entries, clean=True)
 
+        # when processing single entries, all H2 polymorphs will get assigned the
+        # same energy
+        if len(entries) == 1 and entries[0].composition.reduced_formula == "H2":
+            warnings.warn(
+                "Processing single H2 entries will result in the all polymorphs "
+                "being assigned the same energy. This should not cause problems "
+                "with Pourbaix diagram construction, but may be confusing. "
+                "Pass all entries to process_entries() at once in if you want to "
+                "preserve H2 polymorph energy differences."
+            )
+
         # extract the DFT energies of oxygen and water from the list of entries, if present
-        if not self.o2_energy:
-            o2_entries = [e for e in entries if e.composition.reduced_formula == "O2"]
-            if o2_entries:
-                self.o2_energy = min(e.energy_per_atom for e in o2_entries)
+        # do not do this when processing a single entry, as it might lead to unintended
+        # results
+        if len(entries) > 1:
+            if not self.o2_energy:
+                o2_entries = [e for e in entries if e.composition.reduced_formula == "O2"]
+                if o2_entries:
+                    self.o2_energy = min(e.energy_per_atom for e in o2_entries)
 
-        if not self.h2o_energy and not self.h2o_adjustments:
-            h2o_entries = [e for e in entries if e.composition.reduced_formula == "H2O"]
-            if h2o_entries:
-                h2o_entries = sorted(h2o_entries, key=lambda e: e.energy_per_atom)
-                self.h2o_energy = h2o_entries[0].energy_per_atom
-                self.h2o_adjustments = h2o_entries[0].correction / h2o_entries[0].composition.num_atoms
+            if not self.h2o_energy and not self.h2o_adjustments:
+                h2o_entries = [e for e in entries if e.composition.reduced_formula == "H2O"]
+                if h2o_entries:
+                    h2o_entries = sorted(h2o_entries, key=lambda e: e.energy_per_atom)
+                    self.h2o_energy = h2o_entries[0].energy_per_atom
+                    self.h2o_adjustments = h2o_entries[0].correction / h2o_entries[0].composition.num_atoms
 
-        return super().process_entries(entries, clean=clean)
+        h2_entries = [e for e in entries if e.composition.reduced_formula == "H2"]
+        if h2_entries:
+            h2_entries = sorted(h2_entries, key=lambda e: e.energy_per_atom)
+            self.h2_energy = h2_entries[0].energy_per_atom  # type: ignore
+
+        return super().process_entries(entries, clean=clean, verbose=verbose)
