@@ -68,16 +68,12 @@ class AdfInputError(Exception):
     The default error class for ADF.
     """
 
-    pass
-
 
 class AdfOutputError(Exception):
     """
     The default error class for errors raised by ``AdfOutput``.
     """
 
-    pass
-
 
 class AdfKey(MSONable):
     """
@@ -152,9 +148,9 @@ class AdfKey(MSONable):
             s = ""
             for op in self.options:
                 if self._sized_op:
-                    s += "{:s}={:s} ".format(*map(str, op))
+                    s += f"{op[0]}={op[1]} "
                 else:
-                    s += "{:s} ".format(str(op))
+                    s += f"{op} "
             return s.strip()
         return ""
 
@@ -184,9 +180,9 @@ class AdfKey(MSONable):
         different string format will be used.
 
         """
-        s = "{:s}".format(self.key)
+        s = f"{self.key}"
         if len(self.options) > 0:
-            s += " {:s}".format(self._options_string())
+            s += f" {self._options_string()}"
         s += "\n"
         if len(self.subkeys) > 0:
             if self.key.lower() == "atoms":
@@ -263,8 +259,8 @@ class AdfKey(MSONable):
         """
         if len(self.subkeys) > 0:
             key = subkey if isinstance(subkey, str) else subkey.key
-            for i in range(len(self.subkeys)):
-                if self.subkeys[i].key == key:
+            for i, v in enumerate(self.subkeys):
+                if v.key == key:
                     self.subkeys.pop(i)
                     break
 
@@ -275,7 +271,7 @@ class AdfKey(MSONable):
         Parameters
         ----------
         option : Sized or str or int or float
-            A new option to add. This must have the same format with exsiting
+            A new option to add. This must have the same format with existing
             options.
 
         Raises
@@ -311,8 +307,8 @@ class AdfKey(MSONable):
             if self._sized_op:
                 if not isinstance(option, str):
                     raise TypeError("``option`` should be a name string!")
-                for i in range(len(self.options)):
-                    if self.options[i][0] == option:
+                for i, v in enumerate(self.options):
+                    if v[0] == option:
                         self.options.pop(i)
                         break
             else:
@@ -472,10 +468,10 @@ class AdfTask(MSONable):
 
     operations = {
         "energy": "Evaluate the single point energy.",
-        "optimize": "Minimize the energy by varying the molecular " "structure.",
-        "frequencies": "Compute second derivatives and print out an " "analysis of molecular vibrations.",
+        "optimize": "Minimize the energy by varying the molecular structure.",
+        "frequencies": "Compute second derivatives and print out an analysis of molecular vibrations.",
         "freq": "Same as frequencies.",
-        "numerical_frequencies": "Compute molecular frequencies using" " numerical method.",
+        "numerical_frequencies": "Compute molecular frequencies using numerical method.",
     }
 
     def __init__(
@@ -513,7 +509,7 @@ class AdfTask(MSONable):
 
         """
         if operation not in self.operations.keys():
-            raise AdfInputError("Invalid ADF task {:s}".format(operation))
+            raise AdfInputError(f"Invalid ADF task {operation}")
         self.operation = operation
         self.title = title
         self.basis_set = basis_set if basis_set is not None else self.get_default_basis_set()
@@ -606,7 +602,7 @@ class AdfTask(MSONable):
         s += "\n"
         for block_key in self.other_directives:
             if not isinstance(block_key, AdfKey):
-                raise ValueError("{} is not an AdfKey!".format(str(block_key)))
+                raise ValueError(f"{block_key} is not an AdfKey!")
             s += str(block_key) + "\n"
         return s
 
@@ -773,7 +769,7 @@ class AdfOutput:
         workdir = os.path.dirname(self.filename)
         logfile = os.path.join(workdir, "logfile")
         if not os.path.isfile(logfile):
-            raise IOError("The ADF logfile can not be accessed!")
+            raise OSError("The ADF logfile can not be accessed!")
 
         self.is_failed = False
         self.error = None
@@ -816,7 +812,7 @@ class AdfOutput:
 
         cycle_patt = re.compile(r"Coordinates\sin\sGeometry\sCycle\s(\d+)")
         coord_patt = re.compile(r"\s+([0-9]+)\.([A-Za-z]+)" + 3 * r"\s+([-\.0-9]+)")
-        energy_patt = re.compile(r"<.*>\s<.*>\s+current\senergy\s+([-\.0-9]+)\s" "Hartree")
+        energy_patt = re.compile(r"<.*>\s<.*>\s+current\senergy\s+([-\.0-9]+)\sHartree")
         final_energy_patt = re.compile(r"<.*>\s<.*>\s+Bond\sEnergy\s+([-\.0-9]+)\sa\.u\.")
         error_patt = re.compile(r"<.*>\s<.*>\s+ERROR\sDETECTED:\s(.*)")
         runtype_patt = re.compile(r"<.*>\s<.*>\s+RunType\s+:\s(.*)")
@@ -830,7 +826,7 @@ class AdfOutput:
         # The last non-empty line of the logfile must match the end pattern.
         # Otherwise the job has some internal failure. The TAPE13 part of the
         # ADF manual has a detailed explanantion.
-        with open(logfile, "r") as f:
+        with open(logfile) as f:
             for line in reverse_readline(f):
                 if line == "":
                     continue
@@ -841,7 +837,7 @@ class AdfOutput:
                     return
                 break
 
-        with open(logfile, "r") as f:
+        with open(logfile) as f:
             for line in f:
                 m = error_patt.search(line)
                 if m:
@@ -879,7 +875,7 @@ class AdfOutput:
                     if m:
                         cycle = int(m.group(1))
                         if cycle <= 0:
-                            raise AdfOutputError("Wrong cycle {}".format(cycle))
+                            raise AdfOutputError(f"Wrong cycle {cycle}")
                         if cycle > last_cycle:
                             parse_cycle = True
                             last_cycle = cycle
@@ -946,7 +942,7 @@ class AdfOutput:
             parse_coord = False
             natoms = self.final_structure.num_sites
 
-        with open(self.filename, "r") as f:
+        with open(self.filename) as f:
             for line in f:
                 if self.run_type == "NumericalFreq" and find_structure:
                     if not parse_coord:
